<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Management.Update

Windows Runtime (WinRT) APIs for for the `Windows.Management.Update` namespace.

This package provides the `winrt.windows.management.update` module.
